@@ -24,12 +24,12 @@ package Buildd::Mail;
 use strict;
 use warnings;
 
-use Buildd qw(ll_send_mail lock_file unlock_file send_mail);
+use Buildd qw(ll_send_mail lock_file unlock_file send_mail exitstatus);
 use Buildd::Conf qw();
 use Buildd::Base;
 use Sbuild qw(binNMU_version $devnull);
 use Sbuild::ChrootRoot;
-use Sbuild::DB::Client;
+use Buildd::Client;
 use POSIX;
 use File::Basename;
 use MIME::QuotedPrint;
@@ -478,6 +478,8 @@ sub prepare_for_upload ($$) {
     my $pkg = shift;
     my $changes = shift;
 
+    $changes =~ s/\n+$/\n/;
+
     my( @files, @md5, @missing, @md5fail, $i );
 
     my @to_dists = $self->get_dists_from_changes( $changes );
@@ -1105,7 +1107,32 @@ sub get_fail_msg ($$) {
     }
 }
 
-sub check_state ($$@) {
+sub check_state ($@) {
+    my $self = shift;
+    my $mail_error = $self->get('Mail Error');
+    my $retval = $self->check_state_internal(@_);
+    # check if we should retry the call
+    if ($retval == -1) {
+	my $interval = int(rand(120));
+	$self->log("Retrying --info in $interval seconds...\n");
+	# reset error to old value
+	$self->set('Mail Error', $mail_error);
+	# 0..120s of sleep ought to be enough for retrying;
+	# for mail bursts, this should get us out of the
+	# crticial mass
+	sleep $interval;
+	$retval = $self->check_state_internal(@_);
+	# remap the -1 retry code to failure
+	if ($retval == -1) {
+	    return 0;
+	} else {
+	    return $retval;
+	}
+    }
+    return $retval;
+}
+
+sub check_state_internal ($$@) {
     my $self = shift;
     my $pkgv = shift;
     my $dist_config = shift;
@@ -1121,7 +1148,9 @@ sub check_state ($$@) {
 	$self->set('Mail Error',
 		   $self->get('Mail Error') .
 		   "Couldn't start wanna-build --info: $!\n");
-	return 0;
+	$self->log("Couldn't start wanna-build --info: $!\n");
+	# let check_state() retry if needed
+	return -1;
     }
 
     my ($av, $as, $ab, $an);
@@ -1133,6 +1162,14 @@ sub check_state ($$@) {
     }
     close($pipe);
 
+    if ($?) {
+	my $t = "wanna-build --info failed with status ".exitstatus($?)."\n";
+	$self->log($t);
+	$self->set('Mail Error',
+		   $self->get('Mail Error') . $t);
+	return 0;
+    }
+
     my $msg = "$pkgv($dist_name) check_state(@wanted_states): ";
     $av = binNMU_version($av,$an,undef) if (defined $an);
     if ($av ne $vers) {
